@@ -21,7 +21,14 @@ namespace Givaro {
     Target& Caster (Target& t, const Source& s) {
         return t = static_cast<Target>(s);
     }
+
+    template <typename Target, typename Source>
+    Target Caster (const Source& s) {
+        Target tmp;
+        return Caster(tmp, s);
+    }
 }
 
 #endif // __GIVARO_caster_H
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+/* -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
